@@ -62,6 +62,39 @@ def filename_to_file_opts(filename):
                 if matches.group('conf') is not None:
                     # optional option
                     file_opts['conf'] = matches.group('conf')
+    elif filename.startswith('gluster'):
+        filename_pattern = re.compile(
+            r'gluster\+?(?P<type>.+)?://((?P<host>[^/]+?)(:(?P<port>\d+))?)?/'
+            r'(?P<volume>.+?)/(?P<path>[^,?]+)'
+            r'(\?socket=(?P<socket>[^,]+))?'
+        )
+        matches = filename_pattern.match(filename)
+        if matches:
+            servers = []
+            transport = 'inet' if not matches.group('type') or matches.group('type') == 'tcp' else matches.group('type')
+
+            if matches.group('host'):
+                # 'IPv4/hostname' or '[IPv6 address]'
+                host = matches.group('host').strip('[]')
+
+                # port should be set for both qemu-img and qemu-kvm
+                port = matches.group('port') if matches.group('port') else '0'
+
+                servers.append({'type': transport,
+                                'host': host,
+                                'port': port})
+            elif matches.group('socket'):
+                servers.append({'type': transport,
+                                'path': matches.group('socket')})
+
+            if matches.group('volume') and matches.group('path') and servers:
+                # required options for gluster
+                file_opts = {'driver': 'gluster',
+                             'volume': matches.group('volume'),
+                             'path': matches.group('path')}
+                file_opts.update({'server.{i}.{k}'.format(i=i, k=k): v
+                                 for i, server in enumerate(servers)
+                                 for k, v in six.iteritems(server)})
     # FIXME: Judge the host device by the string starts with "/dev/".
     elif filename.startswith('/dev/'):
         file_opts = {'driver': 'host_device', 'filename': filename}
@@ -106,6 +139,25 @@ def _get_image_meta(image, params, root_dir):
                 meta['file']['password'] = auth_info.data
             if auth_info.iscsi_initiator:
                 meta['file']['initiator-name'] = auth_info.iscsi_initiator
+        elif auth_info.storage_type == 'glusterfs-direct':
+            if auth_info.debug:
+                meta['file']['debug'] = int(auth_info.debug)
+            if auth_info.logfile:
+                meta['file']['logfile'] = auth_info.logfile
+
+            peers = []
+            for peer in auth_info.peers:
+                if 'path' in peer:
+                    # access storage with unix domain socket
+                    peers.append({'type': 'unix', 'path': peer['path']})
+                else:
+                    # access storage with hostname/ip + port
+                    peers.append({'host': peer['host'],
+                                  'type': peer.get('type', 'inet'),
+                                  'port': '%s' % peer.get('port', '0')})
+            meta['file'].update({'server.{i}.{k}'.format(i=i+1, k=k): v
+                                for i, server in enumerate(peers)
+                                for k, v in six.iteritems(server)})
 
     return meta
 
@@ -166,6 +218,10 @@ def get_image_repr(image, params, root_dir, representation=None):
                 # besides u/p, iscsi access may need initiator
                 if auth_info.iscsi_initiator:
                     access_needed = True
+            elif auth_info.storage_type == 'glusterfs-direct':
+                # debug, logfile and other servers represent in json
+                if auth_info.debug or auth_info.logfile or auth_info.peers:
+                    access_needed = True
 
         func = mapping["json"] if image_secret or access_needed else mapping["filename"]
     return func(image, params, root_dir)
