@@ -375,10 +375,10 @@ class HugePageConfig(object):
         self.qemu_overhead = int(params.get("hugepages_qemu_overhead", 128))
         self.deallocate = params.get("hugepages_deallocate", "yes") == "yes"
         self.hugepage_path = '/mnt/kvm_hugepage'
-        if os.path.exists('/proc/sys/vm/nr_hugepages'):
-            self.kernel_hp_file = '/proc/sys/vm/nr_hugepages'
-        else:
-            raise exceptions.TestSkipError("System doesn't support hugepages")
+        self.kernel_hp_file = params.get("kernel_hp_file", "/proc/sys/vm/nr_hugepages")
+        if not os.path.exists(self.kernel_hp_file):
+            raise exceptions.TestSkipError("Hugepage config file is not found: "
+                                           "%s" % self.kernel_hp_file)
         self.over_commit_hp = "/proc/sys/vm/nr_overcommit_hugepages"
         self.over_commit = kernel_interface.ProcFS(self.over_commit_hp)
         self.pool_path = "/sys/kernel/mm/hugepages"
@@ -503,7 +503,7 @@ class HugePageConfig(object):
             with open(self.kernel_hp_file, "r") as hugepage_allocated:
                 available_hugepages = int(hugepage_allocated.read().strip())
             chunk_bottom = int(math.log(self.hugepage_size / utils_memory.getpagesize(), 2))
-            if ARCH == 'ppc64le':
+            if ARCH in ['ppc64le', 's390x']:
                 chunk_info = utils_memory.get_buddy_info(">=%s" % chunk_bottom)
             else:
                 chunk_info = utils_memory.get_buddy_info(">=%s" % chunk_bottom,
@@ -848,7 +848,7 @@ class PrivateBridgeConfig(object):
 
     def _add_bridge(self):
         self.bridge_manager.add_bridge(self.brname)
-        setbr_cmd = ("ip link set name %s type bridge stp_state 1"
+        setbr_cmd = ("ip link set %s type bridge stp_state 1"
                      " forward_delay 400" % self.brname)
         process.system(setbr_cmd)
         ip_fwd_path = "/proc/sys/net/%s/ip_forward" % self.ip_version
