@@ -550,7 +550,7 @@ class SSHConnection(ConnectionBase):
         server_user = self.server_user
         server_ip = self.server_ip
         ssh = self.SSH
-        if ssh is '/bin/true':
+        if ssh == '/bin/true':
             raise ConnToolNotFoundError('ssh',
                                         "executable not set or found on path, ")
 
@@ -621,7 +621,7 @@ class SSHConnection(ConnectionBase):
                      'shell': shell}
         for tool_name in tool_dict:
             tool = tool_dict[tool_name]
-            if tool is '/bin/true':
+            if tool == '/bin/true':
                 raise ConnToolNotFoundError(tool_name,
                                             "executable not set or found on path,")
 
@@ -1269,8 +1269,8 @@ class TLSConnection(ConnectionBase):
         # edit the /etc/libvirt/libvirtd.conf to add
         # listen_addr=$listen_addr
         if listen_addr:
-            pattern_to_repl[r".*listen_addr\s*=.*"] = \
-                "listen_addr='%s'" % (listen_addr)
+            pattern_to_repl = {r".*listen_addr\s*=.*":
+                               "listen_addr='%s'" % listen_addr}
             operate_libvirtdconf.sub_else_add(pattern_to_repl)
 
         # edit the /etc/libvirt/libvirtd.conf to add auth_tls=$auth_tls
