@@ -212,6 +212,8 @@ class Target(object):
                     'vmx_nfs_src is not set in cfg file, try to guess vmx filename')
                 # some guest's direcotory name ends with '_1',
                 # e.g. esx5.5-win10-x86_64_1/esx5.5-win10-x86_64.vmx
+                #
+                # Note: the pattern order cannot be changed
                 guess_ptn_list = [r'(^.*?(x86_64|i386))_[0-9]+$',
                                   r'(^.*?(x86_64|i386)$)',
                                   r'(^.*?)_[0-9]+$']
@@ -592,7 +594,7 @@ class LinuxVMCheck(VMCheck):
         """
         Get vm pci list.
         """
-        cmd_list = ['lspci', 'lshw']
+        cmd_list = ['lspci', 'lshw', 'hwinfo']
         return self.run_cmd(cmd_list)[1]
 
     def get_vm_rc_local(self):
@@ -976,6 +978,17 @@ class WindowsVMCheck(VMCheck):
         cmd = r"dir %s\Drivers\VirtIO\\viostor.sys" % self.windows_root
         return self.run_cmd(cmd)[1]
 
+    def get_service_info(self, name=None):
+        """
+        Get service info.
+
+        :param name: an optional service name
+        """
+        cmd = r"sc query"
+        if name:
+            cmd += ' ' + name
+        return self.run_cmd(cmd)[1]
+
     def get_driver_info(self, signed=True):
         """
         Get windows signed driver info.
@@ -1242,7 +1255,7 @@ def cmd_run(cmd, obj_be_cleaned=None, auto_clean=True, timeout=18000):
                 for obj in obj_be_cleaned:
                     obj.cleanup()
             else:
-                obj.cleanup()
+                obj_be_cleaned.cleanup()
 
     return cmd_result
 
